@@ -3,13 +3,12 @@
 #
 
 from dj_rql.drf._utils import get_query
-from dj_rql.drf.backend import FilterCache, RQLFilterBackend
+from dj_rql.drf.backend import RQLFilterBackend
 from dj_rql.drf.paginations import RQLContentRangeLimitOffsetPagination, RQLLimitOffsetPagination
 
 
 __all__ = [
     'get_query',
-    'FilterCache',
     'RQLContentRangeLimitOffsetPagination',
     'RQLFilterBackend',
     'RQLLimitOffsetPagination',
